@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from abc import ABCMeta, abstractmethod
-from named_item import NamedItem
+from .named_item import NamedItem
 
 class UniqueIdentifiable(NamedItem):
 
