@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import six
-if six.PY2:
-    import types
+import types
 
 #
 # In python 3 there standard type representations BooleanType, etc.
@@ -12,15 +11,23 @@ if six.PY2:
 # Links:
 # - http://www.diveintopython3.net/porting-code-to-python-3-with-2to3.html#types
 
+MethodType = types.MethodType
+
+if six.PY2:
+    InstanceType = types.InstanceType
+# In PY3 use: type(x)
+
 if six.PY2:
     BooleanType = types.BooleanType
     IntType = types.IntType
     LongType = types.LongType
     FloatType = types.FloatType
     StringType = types.StringType
+    UnicodeType = types.UnicodeType
 else:
     BooleanType = bool
     IntType = int
     LongType = int
     FloatType = float
-    StringType = bytes
\ No newline at end of file
+    StringType = bytes
+    UnicodeType = str
